Learn R Programming

KONPsurv (version 1.0.4)

KONPsurv-package: KONP Tests for Testing the Equality of K Distributions for Right-Censored Data

Description

An implementation of the \(K\)-sample omnibus non-proportional hazrds (KONP) tests.

The KONP tests are powerful non-parametric tests for comparing \(K\) (>=2) hazard functions based on right-censored data. These tests are consistent against any differences between the hazard functions of the groups. The KONP tests are often more powerful than other existing tests, especially under non-proportional hazard functions.

Arguments

Details

The package contains one function:

konp_test: non-parametric tests for equality of \(K\) distributions using right-censored data.

References

Gorfine, M., Schlesinger, M., & Hsu, L. (2020). \(K\)-sample omnibus non-proportional hazards tests based on right-censored data. Statistical Methods in Medical Research, 29(10), 2830<U+2013>2850. 10.1177/0962280220907355

Examples

Run this code
# NOT RUN {
  
# }
# NOT RUN {
# gastric cancer data  
data(gastric)

konp_test(gastric$time, gastric$status, gastric$group, n_perm=10^3)
  
# }

Run the code above in your browser using DataLab