Learn R Programming

KONPsurv (version 1.0.4)

konp_test: KONP tests are \(K\)-sample Omnibus Non-Proportional hazards tests for right-censored data.

Description

KONP tests are \(K\)-sample Omnibus Non-Proportional hazards tests for right-censored data.

Usage

konp_test(time, status, group, n_perm, n_impu = 1)

Arguments

time

A vector of the observed follow-up times.

status

A vector of event indicators, 0=right censored, 1= event at time.

group

A vector denoting the group labels, must contain at least two different values.

n_perm

The number of permutations.

n_impu

The number of imputations, for each imputation n_perm permutations will be executed.

Value

Three test statistics and their respective p-values are returned:

pv_chisq - returns the p-value based on the KONP test chi-square statistic. pv_lr - returns the p-value based on the KONP test likelihood ratio statistic. pv_cauchy - returns the p-value based on the KONP-based Cauchy-combination test statistic. chisq_test_stat - returns the KONP test chi-squared test statistic. lr_test_stat - returns the KONP test likelihood-ratio test statistic. cauchy_test_stat - returns the KONP-based Cauchy-combination test statistic.

Details

The KONP tests are powerful non-parametric tests for comparing \(K\) (>=2) hazard functions based on right-censored data. These tests are consistent against any differences between the hazard functions of the groups. The KONP tests are often more powerful than other existing tests, especially under non-proportional hazard functions.

Examples

Run this code
# NOT RUN {
# gastric cancer data
data(gastric)

konp_test(gastric$time, gastric$status, gastric$group, n_perm=10^3) 

# }

Run the code above in your browser using DataLab